@@ -29,4 +29,4 @@ class Runner:
         self.check_exist_config()
         color.green("Starting the logicbook server at http://localhost:{}".format(port))
         webbrowser.open("http://localhost:{}".format(port))
-        uvicorn.run(app, host="0.0.0.0", port=port, log_level="critical")
\ No newline at end of file
+        uvicorn.run(app, host="0.0.0.0", port=port, log_level="error")
\ No newline at end of file
